@@ -20,6 +20,11 @@
 
 #include "device.h"
 
+QPulseAudio::Device::State QPulseAudio::Device::state() const
+{
+    return m_state;
+}
+
 QString QPulseAudio::Device::name() const
 {
     return m_name;
@@ -30,6 +35,11 @@ QString QPulseAudio::Device::description() const
     return m_description;
 }
 
+QString QPulseAudio::Device::formFactor() const
+{
+    return m_formFactor;
+}
+
 quint32 QPulseAudio::Device::cardIndex() const
 {
     return m_cardIndex;
@@ -49,3 +59,19 @@ QPulseAudio::Device::Device(QObject *parent)
     : VolumeObject(parent)
 {
 }
+
+QPulseAudio::Device::State QPulseAudio::Device::stateFromPaState(int value) const
+{
+    switch (value) {
+    case -1: // PA_X_INVALID_STATE
+        return InvalidState;
+    case 0:  // PA_X_RUNNING
+        return RunningState;
+    case 1:  // PA_X_IDLE
+        return IdleState;
+    case 2:  // PA_X_SUSPENDED
+        return SuspendedState;
+    default:
+        return UnknownState;
+    }
+}
